@@ -1,4 +1,4 @@
-from print_ext import print, Table, pretty, Printer
+from print_ext import Printer
 from docstring_parser import parse as docstring_parse
 
 
@@ -7,12 +7,15 @@ class CmdDoc():
     def __init__(self, doc):
         self.doc = docstring_parse(doc)
 
-    def pretty(self, fmt='full'):
+
+    def __pretty__(self, fmt='full', **kwargs):
         return getattr(self, f'pretty_{fmt}')()
 
+
     def pretty_short(self):
         return self.doc.short_description
 
+
     def pretty_full(self):
         p = Printer()
         if self.doc.short_description: p('\bem$',self.doc.short_description, pad=(0,1))
