@@ -75,4 +75,11 @@ def printer(**kwargs):
     o = io.StringIO()
     p = Flattener(stream=o, **kwargs)
     return o,p
-   
\ No newline at end of file
+   
+
+def tostr(*args, **kwargs):
+    o,p = printer(**kwargs)
+    p(*args, **kwargs)
+    return o.getvalue()
+
+    
\ No newline at end of file
